<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>MX Boot-reparation</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="45"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>MX Boot-reparation är ett redskap som kan användas för att återinstallera GRUB bootloader på ESP (EFI System Partition), MBR (Master Boot Record) eller rotpartitionen. Det ger möjligheten att rekonstruera GRUBs konfigurationsfil och att säkerhetskopiera och återställa MBR eller PBR (rot).</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="64"/>
        <source>What would you like to do?</source>
        <translation>Vad vill du göra?</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="94"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Säkerhetskopiera MBR eller PBR (enbart för legacy boot)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="70"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Återinstallera GRUB bootloader på ESP, MBR eller PBR (root)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="80"/>
        <source>Repair GRUB configuration file</source>
        <translation>Reparera GRUBs konfigurationsfil</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="87"/>
        <source>Regenerate initramfs images</source>
        <translation>Återskapar initramfs avbildningar</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="101"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Återställ MBR eller PBR från säkerhetskopia (enbart för legacy boot) </translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="134"/>
        <location filename="../src/gui/mainwindow.cpp" line="423"/>
        <source>Select Boot Method</source>
        <translation>Välj Boot-metod</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="152"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="155"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="158"/>
        <location filename="../src/gui/mainwindow.ui" line="398"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="193"/>
        <location filename="../src/gui/mainwindow.cpp" line="424"/>
        <source>Location:</source>
        <translation>Plats:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="218"/>
        <source>EFI System Partition</source>
        <translation>EFI System Partition</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="221"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="240"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Rot (Partition Boot Record)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="243"/>
        <location filename="../src/gui/mainwindow.cpp" line="426"/>
        <source>root</source>
        <translation>rot</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="278"/>
        <location filename="../src/gui/mainwindow.cpp" line="431"/>
        <source>Select root location:</source>
        <translation>Välj rot-plats:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="300"/>
        <location filename="../src/gui/mainwindow.cpp" line="425"/>
        <source>Install on:</source>
        <translation>Installera på:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="389"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="392"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="440"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="443"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="449"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="490"/>
        <source>Cancel any changes then quit</source>
        <translation>Avbryt ändringarna och sedan sluta</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="493"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="499"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="518"/>
        <source>Apply any changes</source>
        <translation>Genomför ändringar</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="521"/>
        <location filename="../src/gui/mainwindow.cpp" line="82"/>
        <source>Next</source>
        <translation>Nästa</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="459"/>
        <source>Apply</source>
        <translation>Använd</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="102"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>GRUB blir installerad på %1 enhet.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="290"/>
        <location filename="../src/gui/mainwindow.cpp" line="348"/>
        <location filename="../src/gui/mainwindow.cpp" line="464"/>
        <location filename="../src/gui/mainwindow.cpp" line="468"/>
        <location filename="../src/gui/mainwindow.cpp" line="475"/>
        <location filename="../src/gui/mainwindow.cpp" line="481"/>
        <location filename="../src/gui/mainwindow.cpp" line="489"/>
        <location filename="../src/gui/mainwindow.cpp" line="496"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="140"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>GRUB konfigurationsfil (grub.cfg) återuppbyggs.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="174"/>
        <source>Generating initramfs images on: %1</source>
        <translation>Skapar initramfs avbildningar på: %1</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="203"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Backar upp MBR eller PBR från %1 enhet.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="259"/>
        <source>Warning</source>
        <translation>Varning</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="260"/>
        <source>You are going to write the content of </source>
        <translation>Du kommer att skriva innehållet av</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="260"/>
        <source> to </source>
        <translation>till</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="261"/>
        <source>

Are you sure?</source>
        <translation>

Är du säker?</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="267"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Återställer MBR/PBR från backup till %1 enhet.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="291"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>Kunde inte hitta EFI system partition (ESP) på någon systemdisk. Var vänlig och skapa en ESP och försök igen.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="303"/>
        <source>Select %1 location:</source>
        <translation>Välj %1 plats:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="326"/>
        <source>Back</source>
        <translation>Bakåt</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="342"/>
        <source>Success</source>
        <translation>Det lyckades</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="342"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>Processen avslutades med framgång.&lt;p&gt;&lt;b&gt;Vill du avsluta MX Boot-reparation?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="348"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Processen avslutad. Fel har inträffat.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="109"/>
        <location filename="../src/gui/mainwindow.cpp" line="148"/>
        <location filename="../src/gui/mainwindow.cpp" line="180"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Skriv in lösenord för att låsa upp %1 krypterad partition:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="430"/>
        <source>Select GRUB location</source>
        <translation>Välj plats för GRUB</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="439"/>
        <source>Select initramfs options</source>
        <translation>Välj initramfs alternativ</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="449"/>
        <source>Select Item to Back Up</source>
        <translation>Välj objekt att backa upp</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="454"/>
        <source>Select Item to Restore</source>
        <translation>Välj objekt att Återställa</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="464"/>
        <location filename="../src/gui/mainwindow.cpp" line="475"/>
        <source>No location was selected.</source>
        <translation>Ingen plats vald.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="469"/>
        <location filename="../src/gui/mainwindow.cpp" line="482"/>
        <source>Please select the root partition of the system you want to fix.</source>
        <translation>Var vänlig välj rotpartitionen på det system du vill reparera.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="487"/>
        <source>Select backup file name</source>
        <translation>Välj filnamn på säkerhetskopian</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="489"/>
        <location filename="../src/gui/mainwindow.cpp" line="496"/>
        <source>No file was selected.</source>
        <translation>Ingen fil valdes.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="494"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Välj MBR eller PBR säkerhetskopia</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="512"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="514"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="515"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Enkelt boot-reparationsprogram för MX Linux</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="517"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="518"/>
        <source>%1 License</source>
        <translation>%1 Licens</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="531"/>
        <source>%1 Help</source>
        <translation>%1 Hjälp</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/gui/about.cpp" line="52"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../src/gui/about.cpp" line="53"/>
        <location filename="../src/gui/about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../src/gui/about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../src/gui/about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="86"/>
        <source>MX Boot Repair</source>
        <translation>MX Boot-reparation</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="94"/>
        <source>MX Boot Repair - GUI and CLI tool for repairing GRUB bootloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="99"/>
        <source>Force CLI mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="100"/>
        <source>Print actions without executing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="101"/>
        <source>Do not prompt; require flags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="102"/>
        <source>Action: install, repair, initramfs, backup, restore</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="103"/>
        <source>Target for install: mbr, esp, root</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="104"/>
        <source>Device for target (e.g., sda, sda1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="105"/>
        <source>Root partition (e.g., /dev/sda2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="106"/>
        <source>Partition to mount at /boot in chroot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="107"/>
        <source>Partition to mount at /boot/efi in chroot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="108"/>
        <source>Path for backup/restore image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="109"/>
        <source>Skip confirmations (for restore)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="110"/>
        <source>Enable verbose output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="111"/>
        <source>Suppress non-error output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="121"/>
        <source>Error: --verbose and --quiet options are mutually exclusive
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="127"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="128"/>
        <source>You must run this program with admin access.</source>
        <translation>Du måste köra detta program med administratörsrättigheter.</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="29"/>
        <source>Invalid index. Try again: </source>
        <translation>Ogiltigt index. Försök igen: </translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="48"/>
        <source>Invalid selection. Enter a number </source>
        <translation>Ogiltigt val. Skriv in en siffra </translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="234"/>
        <source>MX Boot Repair (CLI)</source>
        <translation>MX Boot Repair (CLI)</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="235"/>
        <source>1) Install GRUB</source>
        <translation>1) Installera GRUB</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="236"/>
        <source>2) Repair GRUB (update-grub)</source>
        <translation>2) Reparera GRUB (update-grub)</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="237"/>
        <source>3) Regenerate initramfs</source>
        <translation>3) Regenerera initramfs</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="238"/>
        <source>4) Backup MBR/PBR</source>
        <translation>4) Backup MBR/PBR</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="239"/>
        <source>5) Restore MBR/PBR</source>
        <translation>5) Återställ MBR/PBR</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="240"/>
        <source>q) Quit</source>
        <translation>q) Avsluta</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="241"/>
        <source>Select action [1-5 or &apos;q&apos; to quit]: </source>
        <translation>Välj aktivitet [1-5 eller &apos;q&apos; för att avsluta]: </translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="247"/>
        <source>Invalid selection. Enter 1-5 or &apos;q&apos; to quit.</source>
        <translation>Ogiltigt val. Skriv in 1-5 eller &apos;q&apos; för att avsluta.</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="252"/>
        <source>Target: 0) MBR  1) ESP  2) Root</source>
        <translation>Mål: 0) MBR  1) ESP  2) Root</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="253"/>
        <source>Select target</source>
        <translation>Välj mål</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="259"/>
        <location filename="../src/cli/controller.cpp" line="294"/>
        <location filename="../src/cli/controller.cpp" line="307"/>
        <source>No partitions found. Returning to main menu.</source>
        <translation>Inga partitioner hittade. Återvänder till huvudmeny.</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="263"/>
        <location filename="../src/cli/controller.cpp" line="320"/>
        <location filename="../src/cli/controller.cpp" line="338"/>
        <source>No disks found. Returning to main menu.</source>
        <translation>Inga diskar hittade. Återvänder till huvudmeny..</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="268"/>
        <source>Select disk for MBR (e.g., sda)</source>
        <translation>Väl jdisk för MBR (d.v.s. sda)</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="272"/>
        <source>Select partition for GRUB (e.g., sda1)</source>
        <translation>Välj partition för GRUB (d.v.s. sda1)</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="277"/>
        <source>Select root partition of installed system</source>
        <translation>Välj root partition för det installerade systemet</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="295"/>
        <source>Select root partition to repair</source>
        <translation>Välj root partition att reparera</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="308"/>
        <source>Select root partition to regenerate initramfs</source>
        <translation>Välj root partition att regenerera initramfs</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="321"/>
        <source>Select disk to back up MBR/PBR from</source>
        <translation>Välj disk att backa upp MBR/PBR från</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="324"/>
        <source>Output file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
        <translation>Utdatas filsökväg (eller &apos;b&apos; för att gå tillbaka, &apos;q&apos; för att avsluta): </translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="339"/>
        <source>Select disk to restore MBR/PBR to</source>
        <translation>Välj disk att återställa MBR/PBR till</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="342"/>
        <source>Input backup file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
        <translation>Indatas filsökväg (eller &apos;b&apos; för att gå tillbaka, &apos;q&apos; för att avsluta):</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="349"/>
        <source>WARNING: This will overwrite the first 446 bytes of /dev/</source>
        <translation>VARNING: Detta kommer att skriva över de första 446 bytes på /dev/</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="349"/>
        <source>. Continue? [y/N]: </source>
        <translation>. Fortsätta? [y/N]: </translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="352"/>
        <source>yes</source>
        <comment>confirmation input: full word</comment>
        <translation>ja</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="353"/>
        <source>y</source>
        <comment>confirmation input: single-letter yes</comment>
        <translation>y</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="357"/>
        <source>Cancelled.</source>
        <translation>Stoppad.</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="364"/>
        <source>Unknown selection</source>
        <translation>Okänt val</translation>
    </message>
</context>
</TS>
